==> jc-1.4.5.tar.gz: org/omg/CORBA/IDLType.c <==
// public abstract interface org.omg.CORBA.IDLType

// class file dependencies
// @dep_class 9a35c7173b37e641 java_io_Serializable
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 5d9c93476c19a49d org_omg_CORBA_IDLType
// @dep_class f5b7acb90587f314 org_omg_CORBA_portable_IDLEntity

// header file dependencies
// @dep_header java_io_Serializable
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header org_omg_CORBA_IDLType
// @dep_header org_omg_CORBA_portable_IDLEntity

#include "jc_defs.h"

#include "java/io/Serializable.h"
#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "org/omg/CORBA/IDLType.h"
#include "org/omg/CORBA/portable/IDLEntity.h"

/************************************************************************
 *			       Method list				*
 ************************************************************************/

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_org_omg_CORBA_IDLType$interfaces[] = {
	&_jc_java_io_Serializable$type,
	&_jc_org_omg_CORBA_portable_IDLEntity$type
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_org_omg_CORBA_IDLType$instanceof_hash_bucket_20[] = {
	&_jc_org_omg_CORBA_portable_IDLEntity$type,
	_JC_NULL
};
static _jc_type *const _jc_org_omg_CORBA_IDLType$instanceof_hash_bucket_29[] = {
	&_jc_org_omg_CORBA_IDLType$type,
	_JC_NULL
};
static _jc_type *const _jc_org_omg_CORBA_IDLType$instanceof_hash_bucket_65[] = {
	&_jc_java_io_Serializable$type,
	_JC_NULL
};
static _jc_type *const _jc_org_omg_CORBA_IDLType$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_org_omg_CORBA_IDLType$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[20]=	_jc_org_omg_CORBA_IDLType$instanceof_hash_bucket_20,
	[29]=	_jc_org_omg_CORBA_IDLType$instanceof_hash_bucket_29,
	[65]=	_jc_org_omg_CORBA_IDLType$instanceof_hash_bucket_65,
	[101]=	_jc_org_omg_CORBA_IDLType$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_org_omg_CORBA_IDLType$class_depends[] = {
	{ "java/io/Serializable",	_JC_JLONG(0x9a35c7173b37e641) },
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "org/omg/CORBA/portable/IDLEntity",	_JC_JLONG(0xf5b7acb90587f314) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_org_omg_CORBA_IDLType$vtype _jc_org_omg_CORBA_IDLType$type = {
    .type= {
	.name=			"org/omg/CORBA/IDLType",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT|_JC_ACC_INTERFACE,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_org_omg_CORBA_IDLType$interfaces) / sizeof(*_jc_org_omg_CORBA_IDLType$interfaces),
	.interfaces=		_jc_org_omg_CORBA_IDLType$interfaces,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		11,
		.hash=			_JC_JLONG(0x5d9c93476c19a49d),
		.source_file=		"IDLType.java",
		.num_virtual_refs=	0,
		.instanceof_hash_table=	_jc_org_omg_CORBA_IDLType$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_org_omg_CORBA_IDLType$class_depends) / sizeof(*_jc_org_omg_CORBA_IDLType$class_depends),
		.class_depends=		_jc_org_omg_CORBA_IDLType$class_depends,
	    }
	}
    }
};

==> jc-1.4.6.tar.gz: org/omg/CORBA/IDLType.c <==
// public abstract interface org.omg.CORBA.IDLType

// class file dependencies
// @dep_class 9a35c7173b37e641 java_io_Serializable
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c25a545561a18c38 java_lang_String
// @dep_class 99bf6165eefb06ff org_omg_CORBA_IDLType
// @dep_class 196a5197fe7bdd41 org_omg_CORBA_IDLTypeOperations
// @dep_class a2edbb40d0aebcc3 org_omg_CORBA_IRObject
// @dep_class 6cfb3569aad0c7bf org_omg_CORBA_IRObjectOperations
// @dep_class dfe7f9ea263f4e55 org_omg_CORBA_Object
// @dep_class f5b7acb90587f314 org_omg_CORBA_portable_IDLEntity

// header file dependencies
// @dep_header java_io_Serializable
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header org_omg_CORBA_IDLType
// @dep_header org_omg_CORBA_IDLTypeOperations
// @dep_header org_omg_CORBA_IRObject
// @dep_header org_omg_CORBA_IRObjectOperations
// @dep_header org_omg_CORBA_Object
// @dep_header org_omg_CORBA_portable_IDLEntity

#include "jc_defs.h"

#include "java/io/Serializable.h"
#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "org/omg/CORBA/IDLType.h"
#include "org/omg/CORBA/IDLTypeOperations.h"
#include "org/omg/CORBA/IRObject.h"
#include "org/omg/CORBA/IRObjectOperations.h"
#include "org/omg/CORBA/Object.h"
#include "org/omg/CORBA/portable/IDLEntity.h"

/************************************************************************
 *			       Method list				*
 ************************************************************************/

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_org_omg_CORBA_IDLType$interfaces[] = {
	&_jc_org_omg_CORBA_IDLTypeOperations$type,
	&_jc_org_omg_CORBA_IRObject$type,
	&_jc_org_omg_CORBA_portable_IDLEntity$type,
	&_jc_org_omg_CORBA_Object$type,
	&_jc_java_io_Serializable$type
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_org_omg_CORBA_IDLType$instanceof_hash_bucket_20[] = {
	&_jc_org_omg_CORBA_portable_IDLEntity$type,
	_JC_NULL
};
static _jc_type *const _jc_org_omg_CORBA_IDLType$instanceof_hash_bucket_63[] = {
	&_jc_org_omg_CORBA_IRObjectOperations$type,
	_JC_NULL
};
static _jc_type *const _jc_org_omg_CORBA_IDLType$instanceof_hash_bucket_65[] = {
	&_jc_java_io_Serializable$type,
	&_jc_org_omg_CORBA_IDLTypeOperations$type,
	_JC_NULL
};
static _jc_type *const _jc_org_omg_CORBA_IDLType$instanceof_hash_bucket_67[] = {
	&_jc_org_omg_CORBA_IRObject$type,
	_JC_NULL
};
static _jc_type *const _jc_org_omg_CORBA_IDLType$instanceof_hash_bucket_85[] = {
	&_jc_org_omg_CORBA_Object$type,
	_JC_NULL
};
static _jc_type *const _jc_org_omg_CORBA_IDLType$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};
static _jc_type *const _jc_org_omg_CORBA_IDLType$instanceof_hash_bucket_127[] = {
	&_jc_org_omg_CORBA_IDLType$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_org_omg_CORBA_IDLType$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[20]=	_jc_org_omg_CORBA_IDLType$instanceof_hash_bucket_20,
	[63]=	_jc_org_omg_CORBA_IDLType$instanceof_hash_bucket_63,
	[65]=	_jc_org_omg_CORBA_IDLType$instanceof_hash_bucket_65,
	[67]=	_jc_org_omg_CORBA_IDLType$instanceof_hash_bucket_67,
	[85]=	_jc_org_omg_CORBA_IDLType$instanceof_hash_bucket_85,
	[101]=	_jc_org_omg_CORBA_IDLType$instanceof_hash_bucket_101,
	[127]=	_jc_org_omg_CORBA_IDLType$instanceof_hash_bucket_127
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_org_omg_CORBA_IDLType$class_depends[] = {
	{ "java/io/Serializable",	_JC_JLONG(0x9a35c7173b37e641) },
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0xc25a545561a18c38) },
	{ "org/omg/CORBA/IDLTypeOperations",	_JC_JLONG(0x196a5197fe7bdd41) },
	{ "org/omg/CORBA/IRObject",	_JC_JLONG(0xa2edbb40d0aebcc3) },
	{ "org/omg/CORBA/IRObjectOperations",	_JC_JLONG(0x6cfb3569aad0c7bf) },
	{ "org/omg/CORBA/Object",	_JC_JLONG(0xdfe7f9ea263f4e55) },
	{ "org/omg/CORBA/portable/IDLEntity",	_JC_JLONG(0xf5b7acb90587f314) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_org_omg_CORBA_IDLType$vtype _jc_org_omg_CORBA_IDLType$type = {
    .type= {
	.name=			"org/omg/CORBA/IDLType",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT|_JC_ACC_INTERFACE,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_org_omg_CORBA_IDLType$interfaces) / sizeof(*_jc_org_omg_CORBA_IDLType$interfaces),
	.interfaces=		_jc_org_omg_CORBA_IDLType$interfaces,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		11,
		.hash=			_JC_JLONG(0x99bf6165eefb06ff),
		.source_file=		"IDLType.java",
		.num_virtual_refs=	0,
		.instanceof_hash_table=	_jc_org_omg_CORBA_IDLType$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_org_omg_CORBA_IDLType$class_depends) / sizeof(*_jc_org_omg_CORBA_IDLType$class_depends),
		.class_depends=		_jc_org_omg_CORBA_IDLType$class_depends,
	    }
	}
    }
};
